@@ -16,6 +16,7 @@ EXTENSIONS = {
     'cc': {'text', 'c++'},
     'cu': {'text', 'cuda'},
     'cfg': {'text'},
+    'chs': {'text', 'c2hs'},
     'clj': {'text', 'clojure'},
     'cljc': {'text', 'clojure'},
     'cljs': {'text', 'clojure', 'clojurescript'},
@@ -58,6 +59,7 @@ EXTENSIONS = {
     'gz': {'binary', 'gzip'},
     'h': {'text', 'header', 'c', 'c++'},
     'hpp': {'text', 'header', 'c++'},
+    'hs': {'text', 'haskell'},
     'htm': {'text', 'html'},
     'html': {'text', 'html'},
     'hxx': {'text', 'header', 'c++'},
@@ -86,6 +88,7 @@ EXTENSIONS = {
     'kml': {'text', 'kml', 'xml'},
     'kt': {'text', 'kotlin'},
     'less': {'text', 'less'},
+    'lhs': {'text', 'literate-haskell'},
     'lidr': {'text', 'idris'},
     'lua': {'text', 'lua'},
     'm': {'text', 'c', 'objective-c'},
